.. image:: https://img.shields.io/pypi/v/skeleton.svg
   :target: `PyPI link`_

.. image:: https://img.shields.io/pypi/pyversions/skeleton.svg
   :target: `PyPI link`_

.. _PyPI link: https://pypi.org/project/skeleton

.. image:: https://github.com/jaraco/skeleton/workflows/tests/badge.svg
   :target: https://github.com/jaraco/skeleton/actions?query=workflow%3A%22tests%22
   :alt: tests

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/psf/black
   :alt: Code style: Black

.. .. image:: https://readthedocs.org/projects/skeleton/badge/?version=latest
..    :target: https://skeleton.readthedocs.io/en/latest/?badge=latest

.. image:: https://img.shields.io/badge/skeleton-2021-informational
   :target: https://blog.jaraco.com/skeleton

Pupil Core Network API Client
#############################

This Python module is a client for the `Pupil Core Network API`_. It implements many of
the functionalities demonstrated in the `Pupil Helpers`_.

.. _Pupil Core Network API: https://docs.pupil-labs.com/developer/core/network-api/
.. _Pupil Helpers: https://github.com/pupil-labs/pupil-helpers/tree/master/python

Installation
------------

We recommend installing the pre-packaged binary wheels from PyPI:

.. code-block:: console

    pip install pupil-core-network-client

For more information see the `documentation <https://pupil-core-network-client.readthedocs.io>`_.
